Monty Python's Flying Circus: Just the Words - Episode 21

# Episode Twenty-one

Trailer
'Archaeology Today'
Silly vicar
Leapy Lee
Registrar (wife swap)
Silly doctor sketch (immediately abandoned)
Mr and Mrs Git
Mosquito hunters
Poofy judges
Mrs Thing and Mrs Entity
Beethoven's mynah bird
Shakespeare
Michaelangelo
Colin Mozart (ratcatcher)
Judges

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| BBC 1 World symbol.
Voice Over | Here is a preview of some of the programmes you'll be able to see coming shortly on BBC Television. To kick off with there's variety ... (still picture of Peter West and Brian Johnston) Peter West and Brian Johnston star in 'Rain Stopped Play', a whacky new comedy series about the gay exploits of two television cricket commentators (photo of E. W. Swanton) with E. W. Swanton as Aggie the kooky Scots maid. For those of you who don't like variety, there's variety, with Brian Close at the Talk of the Town. (Brian Close in cricket whites on a stage) And of course there'll be sport. The Classics series (engraving of London and caption: 'The Classics') return to BBC 2 with twenty-six episodes of John Galsworthy's 'Snooker My Way' (composite photo of Nyree Dawn Porter holding a snooker cue) with Nyree Dawn Porter repeating her triumph as Joe Davis. And of course there'll be sport. Comedy is not forgotten (Caption: 'Comedy') with Jim Laker (photo of Laker) in 'Thirteen Weeks of Off-spin Bowling'. Jim plays the zany bachelor bowler in a new series of 'Owzat', with Anneley Brummond-Haye on Mr Softee (photo of same) as his wife. And of course there'll be sport. 'Panorama' will be returning, introduced ('Panorama' caption with photo of Tony Jacklin) as usual by Tony Jacklin, and Lulu (photo of Lulu) will be tackling the Old Man of Hoy (photo of same). And for those of you who prefer drama - there's sport. On 'Show of the Week' Kenneth Wostenholme sings. (still of him, superimposed over Flick Colby Dancers, Pans People, Ono) And for those of you who don't like television there's David Coleman. (picture of him smiling) And of course there'll be sport. But now for something completely different - sport.
| 'Grandstand' signature tune starts and then abruptly cuts into the usual animated credit titles.
| ANIMATION: a sketch about an archaeological find leads to: CAPTION: 'ARCHAEOLOGY TODAY' Interview set for archaeology program. Chairman and two guests sit in chair in front of a blow-up of an old cracked pot.
Interviewer | Hello. On 'Archaeology Today' tonight I have with me Professor Lucien Kastner of Oslo University.
Kastner | Good evening.
Interviewer | How tall are you, professor?
Kastner | ... I beg your pardon?
Interviewer | How tall are you?
Kastner | I'm about five foot ten.
Interviewer | ... and an expert in Egyptian tomb paintings. Sir Robert... (turning to Kastner) are you really five foot ten?
Kastner | Yes.
Interviewer | Funny, you look much shorter than that to me. Are you slumped forward in your chair at all?
Kastner | No, er I...
Interviewer | Extraordinary. Sir Robert Eversley, who's just returned from the excavations in El Ara, and you must be well over six foot. Isn't that right, Sir Robert?
Sir Robert | (puzzled) Yes.
Interviewer | In fact, I think you're six foot five aren't you?
Sir Robert | Yes.
| Applause from off. Sir Robert looks up in amazement.
Interviewer | Oh, that's marvelous. I mean you're a totally different kind of specimen to Professor Kastner. Straight in your seat, erect, firm.
Sir Robert | Yes. I thought we were here to discuss archaeology.
Interviewer | Yes, yes, of course we are, yes, absolutely, you're absolutely right! That's positive thinking for you. (to Kastner) You wouldn't have said a thing like that, would you? You five-foot-ten weed. (he turns his back very ostentatiously on Kastner) Sir Robert Eversley, who's very interesting, what have you discovered in the excavations at El Ara?
Sir Robert | (picking up a beautiful ancient vase) Well basically we have found a complex of tombs...
Interviewer | Very good speaking voice.
Sir Robert | ... which present dramatic evidence of Polynesian influence in Egypt in the third dynasty which is quite remarkable.
Interviewer | How tall were the Polynesians?
Kastner | They were...
Interviewer | Sh!
Sir Robert | Well, they were rather small, seafaring...
Interviewer | Short men, were they... eh? All squat and bent up?
Sir Robert | Well, I really don't know about that...
Interviewer | Who were the tall people?
Sir Robert | I'm afraid I don't know.
Interviewer | Who's that very tall tribe in Africa?
Sir Robert | Well, this is hardly archaeology.
Interviewer | The Watutsi! That's it - the Watutsi! Oh, that's the tribe, some of them were eight foot tall. Can you imagine that. Eight foot of Watutsi. Not one on another's shoulders, oh no - eight foot of solid Watutsi. That's what I call tall.
Sir Robert | Yes, but it's nothing to do with archaeology.
Interviewer | (knocking Sir Robert's vase to the floor) Oh to hell with archaeology!
Kastner | Can I please speak! I came all the way from Oslo to do this program! I'm a professor of archaeology. I'm an expert in ancient civilizations. All right, I'm only five foot ten. All right my posture is bad, all right I slump in my chair. But I've had more women than either of you two! I've had half bloody Norway, that's what I've had! So you can keep your Robert Eversley! And you can keep your bloody Watutsi! I'd rather have my little body... my little five-foot-ten-inch body... (he breaks down sobbing)
Sir Robert | Bloody fool. Look what you've done to him.
Interviewer | Don't bloody fool me.
Sir Robert | I'll do what I like, because I'm six foot five and I eat punks like you for breakfast.
| Sir Robert floors the interviewer with a mighty punch. Interviewer looks up rubbing his jaw.
Interviewer | I'll get you for that, Eversley! I'll get you if I have to travel to the four corners of the earth!
| Crash of music. Music goes into theme and film titles as for a Western. CAPTION: 'FLAMING STAR - THE STORY OF ONE MAN'S SEARCH FOR VENGEANCE IN THE RAW AND VIOLENT WORLD OF INTERNATIONAL ARCHAEOLOGY' Cut to stock film of the pyramids (circa 1920). SUPERIMPOSED CAPTION: 'EGYPT- 1920' An archaeological dig in a flat sandy landscape. All the characters are in twenties' clothes. Pan across the complex of passages and trenches.)
Danielle | (voice over) The dig was going well that year, We had discovered some Hittite baking dishes from the fifth dynasty, and Sir Robert was happier than I had ever seen him.
| Camera comes to rest on Sir Robert Eversley digging away. We close in on him as he sings to Hammond organ accompaniment.
Sir Robert | Today I hear the robin sing Today the thrush is on the wing Today who knows what life will bring Today...
| He stops and picks up an object, blows the dust off it and looks at it wondrously.
Sir Robert | Why, a Sumerian drinking vessel of the fourth dynasty. (sings!) Today!!!! (speaks) Catalogue this pot, Danielle, it's fourth dynasty.
Danielle | Oh, is it... ?
Sir Robert | Yes, it's... Sumerian.
Danielle | Oh, how wonderful! Oh, I am so happy for you.
Sir Robert | I'm happy too, now at last we know there was a Sumerian influence here in Abu Simnel in the early pre-dynastic period, two thousand years before the reign of Tutankhamun, (he breaks into song again) (singing) Today I hear the robin sing Today the thrush is on the wing (Danielle joins in) Today who knows what life will bring.
| They are just about to embrace, when there is a jarring chord and long crash. The interviewer, in the clothes he wore before, is standing on the edge of the dig.
Interviewer | All right Eversley, get up out of that trench.
Sir Robert | Don't forget... I'm six foot five.
Interviewer | That doesn't worry me... Kastner.
| He snaps his fingers. From behind him Professor Kastner appears, fawningly.
Kastner | Here Lord.
Interviewer | Up!
| He snaps his fingers and Kastner leaps onto his shoulders.
Sir Robert | Eleven foot three!
Kastner | I'm so tall! I am so tall!
Sir Robert | Danielle!
| Danielle leaps on his shoulders.
Interviewer | Eleven foot six - damn you! Abdul
| A servant appears on Kastner's shoulders.
Sir Robert | Fifteen foot four! Mustapha!
| A servant appears on Danielle's shoulders.
Interviewer | Nineteen foot three... damn you!
| The six of them charge each other. They fight in amongst the trestle tables with rare pots on them breaking and smashing them. When the fight ends everyone lies dead in a pile of broken pottery. The interviewer crawls up to camera and produces a microphone from his pocket. He is covered in blood and in his final death throes.
Interviewer | And there we end this edition of 'Archaeology Today'. Next week, the Silbury Dig by Cole Porter with Pearl Bailey and Arthur Negus. (he dies)
Voice Over | And now an appeal for sanity from the Reverend Arthur Belling.
| Cut to studio. A vicar sitting facing camera. He has an axe in his head.
Reverend Belling | You know, there are many people in the country today who, through no fault of their own, are sane. Some of them were born sane. Some of them became sane later in their lives. It is up to people like you and me who are out of our tiny little minds to try and help these people overcome their sanity. You can start in small ways with ping-pong ball eyes and a funny voice and then you can paint half of your body red and the other half green and then you can jump up and down in a bowl of treacle going 'squawk, squawk, squawk...' And then you can go 'Neurhhh! Neurhh!' and then you can roll around on the floor going 'pting pting pting' ... (he rolls around on the floor)
Voice Over | The Reverend Arthur Belling is Vicar of St Loony Up The Cream Bun and Jam. And now an appeal on behalf of the National Trust.
| CAPTION: 'AN APPEAL ON BEHALF OF THE NATIONAL TRUSS' Cut to a smartly dressed woman.
Woman | Good evening. My name is Leapy Lee. No, sorry. That's the name of me favourite singer. My name is Mrs Fred Stone. No, no, Mrs Fred Stone is the wife of me favourite tennis player. My name is Bananas. No, no, that's me favourite fruit. I'm Mrs Nice- evening- out- at- the- pictures- then- perhaps- a- dance- at- a- club- and- back- to- his- place- for- a- quick- cup- of- coffee- and- little- bit- of - no! No, sorry, that's me favourite way of spending a night out. Perhaps I am Leapy Lee? Yes! I must be Leapy Lee! Hello fans! Leapy Lee here! (sings) Little arrows that will... (phone rings, she answers) Hello? ... Evidently I'm not Leapy Lee. I thought I probably wouldn't be. Thank you, I'll tell them. (puts phone down) Hello. Hello, Denis Compton here. No no... I should have written it down. Now where's that number? (as she looks in her bag she talks to herself) I'm Mao Tse Tung... I'm P. P. Arnold... I'm Margaret Thatcher ... I'm Sir Gerald Nabarro ... (she dials) Hello? Sir Len Hutton here. Could you tell me, please ... oh, am I? Oh, thank you. (puts phone down) Good evening. I'm Mrs What-number-are-you-dialing-please?
| A boxer (Terry G) rushes in and fells her with one blow. After Women's Institute applauding cut to: a man coming through a door with a neat little bride in a bridal dress. The man walks up to the registrar who is sitting at his desk with a sign saying 'Registrar of Marriages '.
Man | Good morning.
Registrar | Good morning.
Man | Are you the registrar?
Registrar | I have that function.
Man | I was here on Saturday, getting married to a blond girl, and I'd like to change please. I'd like to have this one instead please.
Registrar | What do you mean?
Man | Er, well, the other one wasn't any good, so I'd like to swap it for this one, please. Er, I have paid. I paid on Saturday. Here's the ticket. (gives him the marriage licence.)
Registrar | Ah, oh, no. That was when you were married.
Man | Er, yes. That was when I was married to the wrong one. I didn't like the colour. This is the one I want to have, so if you could just change the forms round I can take this one back with me now.
Registrar | I can't do that.
Man | Look, make it simpler, I'll pay again.
Registrar | No, you can't do that.
Man | Look, all I want you to do is change the wife, say the words, blah, blab, blah, back to my place, no questions asked.
Registrar | I'm sorry sir, but we're not allowed to change.
Man | You can at Harrods.
Registrar | You can't.
Man | You can. I changed my record player and there wasn't a grumble.
Registrar | It's different.
Man | And I changed my pet snake, and I changed my Robin Day tie.
Registrar | Well, you can't change a bloody wife!
Man | Oh, all right! Well, can I borrow one for the weekend.
Registrar | No!
Man | Oh, blimey, I only wanted a jolly good...
| A whistle blows. A referee runs on, takes his book out and proceeds to take the name of the man in the registry office, amidst protests.
Referee | All right, break it up. What's your number, then? All right. Name?
Man | Cook.
| Cut to the two in the next sketch waiting. Cut back to referee, who finishes booking the man and blows his whistle. The show continues. Cut to the two waiting. On the sound of the whistle they start acting.
Doctor | Next please. Name?
Watson | Er, Watson.
Doctor | (writing it down) Mr Watson.
Watson | Ah, no, Doctor.
Doctor | Ah, Mr Doctor.
Watson | No, not Mr, Doctor.
Doctor | Oh, Doctor Doctor.
Watson | No, Doctor Watson.
Doctor | Oh, Doctor Watson Doctor.
Watson | Oh, just call me darling.
Doctor | Hello, Mr Darling.
Watson | No, Doctor.
Doctor | Hello Doctor Darling.
| Sound of whistle; instant cut to: CAPTION: 'THAT SKETCH HAS BEEN ABANDONED' Animation sketch leads us into a cocktail party in Dulwich. Quiet party-type music. Constant chatter.
Host | Ah, John. Allow me to introduce my next-door neighbour. John Stokes, this is A Snivelling Little Rat-Faced Git. Ah!
Mr Git | Hello, I noticed a slight look of anxiety cross your face for a moment just then, but you needn't worry - I'm used to it. That's the trouble of having a surname like Git.
John | Oh ... yes, yes.
Mr Git | We did think once of having it changed by deed-poll, you know - to Watson or something like that. But A Snivelling Little Rat-Faced Watson's just as bad eh?
John | Yes, yes, I suppose so.
| Mrs Git approaches.
Mr Git | Oh, that's my wife. Darling! Come and meet Mr... what was it?
John | Stokes - John Stokes.
Mr Git | Oh yes. John Stokes, this is my wife, Dreary Fat Boring Old.
John | Oh, er, how do you do.
Mrs Git | How do you do.
| Mrs Stokes appears.
Mrs Stokes | Darling, there you are!
John | Yes, yes, here I am, yes.
Mr Git | Oh, is this your wife?
John | Yes, yes, yes, this is the wife. Yes. Um darling, these, these are the Gits.
Mrs Stokes | (slightly shocked) What?
John | The Gits.
Mr Git | Oh, heaven's sakes we are being formal. Does it have to be surnames?
John | Oh, no, no. Not at all. No. Um, no, this... this... this is my wife Norah, er, Norah Jane, Norah Jane Stokes. This is Snivelling Little Rat-Faced Git. And this is his wife Dreary Fat Boring Old Git.
Mr Git | I was just telling your husband what an awful bore it is having a surname like Git.
Mrs Stokes | (understanding at last) OH Oh well, it's not that bad.
Mr Git | Oh, you've no idea how the kids get taunted. Why, only last week Dirty Lying Little Two-Faced came running home from school, sobbing his eyes out, and our youngest, Ghastly Spotty Horrible Vicious Little is just at the age when taunts like 'she's a git' really hurt. Yes.
| Mrs Git gobs colourfully into her handbag.
John | Do ... do you live round here?
Mr Git | Yes, we live up the road, number 49 - you can't miss it. We've just had the outside painted with warm pus.
John | (with increasing embarrassment) Oh.
Mr Git | Yes. It's very nice actually. It goes nicely with the vomit and catarrh we've got smeared all over the front door.
Mrs Stokes | I think we ought to be going. We have two children to collect.
Mr Git | Oh, well, bring them round for tea tomorrow.
Mrs Stokes | Well...
Mr Git | It's Ghastly Spotty Cross-Eyed's birthday and she's having a disembowelling party for a few friends. The Nauseas will be there, and Doug and Janice Mucus, and the Rectums from Swanage.
Voice Over | (and CAPTION:) 'AND NOW A NICE VERSION OF THAT SAME SKETCH' Cut to exactly the same set-up as before.
Host | John! Allow me to introduce our next-door neighhour. John, this is Mr Watson.
Watson | Hello. I noticed a slight look of anxiety cross your face just then but you needn't worry.
| Cut to nun.
Nun | I preferred the dirty version.
| She is knocked out by the boxer. Cut to Women's Institute applause film. Big close-up Hank Spim (face only). He is obviously walking along, the camera is following him hand held.
Hank | Well, I've been a hunter all my life. I love animals. That's why I like to kill 'em. I wouldn't kill an animal I didn't like. Goodday Roy.
| Pull back to reveal he is walking with his brother in fairly rough country location. They pull a small trailer with 'high explosives' written in large letters on the side. The trailer has bombs in it. Hank takes a bazooka from the trailer.
Voice Over | Hank and Roy Spim are tough, fearless backwoodsmen who have chosen to live in a violent, unrelenting world of nature's creatures, where only the fittest survive. Today they are off to hunt mosquitoes.
| Big close-up Roy Spim. He is obviously searching for something.
Roy | (voice over) The mosquito's a clever little bastard. You can track him for days and days until you really get to know him like a friend. He knows you're there, and you know he's there. It's a game of wits. You hate him, then you respect him, then you kill him.
| Cut to Hank Spim who stands peering toward the horizon. Suddenly he points.
Voice Over | Suddenly Hank spots the mosquito they're after.
| Dramatic music. Crash zoom along Hank's eyeline to as big a close-up as we can get of a patch in a perfectly ordinary field. Cut back to Hank and Roy starting to crawl towards some bushes.
Voice Over | Now more than ever, they must rely on the skills they have learnt from a lifetime's hunting. (tense music, as they worm their way forward) Hank gauges the wind. (shot of Hank doing complicated wind gauging biz.) Roy examines the mosquito's spoor. (shot of Roy examining the ground intently) Then ... (Roy fires a bazooka. Hank fires off a machine gun; a series of almighty explosions in the small patch of field; the gunfire stops and the smoke begins to clear) It's a success. The mosquito now is dead. (Hank and Roy approach the scorched and blackened patch in the field) But Roy must make sure. (Roy points machine gun at head of mosquito and fires off another few rounds)
Roy | There's nothing more dangerous than a wounded mosquito.
Voice Over | But the hunt is not over. With well practised skill Hank skins the mosquito. (Hank produces an enormous curved knife and begins to start skinning the tiny mosquito) The wings of a fully grown male mosquito can in fact fetch anything up to point eight of a penny on the open market. (shot of them walking, carrying weapons) The long day is over and it's back to base camp for a night's rest. (inside villa; Hank is cleaning bazooka) Here, surrounded by their trophies Roy and Hank prepare for a much tougher ordeal - a moth hunt.
Hank | Well, I follow the moth in the helicopter to lure it away from the flowers, and then Roy comes along in the Lockheed Starfighter and attacks it with air-to-air missiles.
Roy | A lot of people have asked us why we don't use fly spray. Well, where's the sport in that?
| Shot of them driving in Land Rover heavily loaded with weapons.
Voice Over | For Roy, sport is everything. Ever since he lost his left arm battling with an ant, Roy has risked his life in the pursuit of tiny creatures. (a peaceful river bank; Roy and Hank are fishing) But it's not all work and for relaxation they like nothing more than a day's fishing. (Hank presses a button and there is a tremendous explosion in the water) Wherever there is a challenge, Hank and Roy Spim will be there ready to carry on this primordial struggle between man and inoffensive, tiny insects.
| Pull out to reveal the brothers standing on a tank. Heroic music reaches a climax. Apropos of nothing cut to oak-panelled robing chamber in the Old Bailey. Two Judges in full wigs and red robes enter.
First Judge | (very camp) Oh, I've had such a morning in the High Court. I could stamp my little feet the way those QC's carry on.
Second Judge | (just as camp) Don't I know it, love.
First Judge | Objection here, objection there! And that nice policeman giving his evidence so well - beautiful speaking voice ... well after a bit all I could do was bang my little gavel.
Second Judge | You what, love?
First Judge | I banged me gavel. I did me 'silence in court' bit. Ooh! If looks could kill that prosecuting counsel would be in for thirty years. How did your summing up go?
Second Judge | Well, I was quite pleased actually. I was trying to do my butch voice, you know, 'what the jury must understand', and they loved it, you know. I could see that foreman eyeing me.
First Judge | Really?
Second Judge | Yes, cheeky devil.
First Judge | Was he that tall man with that very big... ?
Second Judge | No, just a minute - I must finish you know. Anyway, I finished up with 'the actions of these vicious men is a violent stain on the community and the full penalty of the law is scarcely sufficient to deal with their ghastly crimes', and I waggled my wig! Just ever so slightly, but it was a stunning effect.
First Judge | Oh, I bet it was... like that super time I wore that striped robe in the Magistrates Court.
Second Judge | Oh, aye.
| Fade out. Fade into a bench in a public park, garden or square. A pepperpot is sitting on the bench. Another pepperpot comes by pushing a shopping trolley.
First Pepperpot | Hello, Mrs Thing.
Second Pepperpot | Hello, Mrs Entity.
First Pepperpot | How are you then?
Second Pepperpot | Oh, I have had a morning.
First Pepperpot | Busy?
Second Pepperpot | Busy - huh! I got up at five o'dock, I made myself a cup of tea, I looked out of the window. Well, by then I was so worn out I had to come and have a sit-down. I've been here for seven hours.
First Pepperpot | You must be exhausted.
Second Pepperpot | Mm. Oh, have you been shopping?
First Pepperpot | No, I've been shopping.
Second Pepperpot | Funny.
First Pepperpot | I'm worn out. I've been shopping for six hours.
Second Pepperpot | What have you bought, then?
First Pepperpot | Nothing. Nothing at all. A complete waste of time.
Second Pepperpot | Wicked, isn't it?
First Pepperpot | Wicked. It'll be worse when we join the Common Market.
Second Pepperpot | That nice Mr Heath would never allow that.
First Pepperpot | It's funny he never married.
Second Pepperpot | He's a bachelor.
First Pepperpot | Oooh! That would explain it, Oh dear me, this chatting away wears me out.
Second Pepperpot | Yes. I bet Mrs Reginald Maudling doesn't have to put up with all this drudgery, getting up at five in the morning, making a cup of tea, looking out of the window, chatting away.
First Pepperpot | No! It'd all be done for her.
Second Pepperpot | Yes, she'd have the whole day free for playing snooker.
First Pepperpot | She probably wouldn't go through all the drudgery of playing snooker, day in, day out.
Second Pepperpot | No, it would all be done for her. She wouldn't even have to lift the cue.
First Pepperpot | She probably doesn't even know where the billlard room is.
Second Pepperpot | No, still, it's not as bad as the old days. Mrs Stanley Baldwin used to have to get up at five o'clock in the morning and go out and catch partridges with her bare hands.
First Pepperpot | Yes... and Mrs William Pitt the Elder used to have to get up at three o'clock and go burrowing for truffles with the bridge of her nose.
Second Pepperpot | Mrs Beethoven used to have to get up at midnight to spur on the mynah bird.
First Pepperpot | Lazy creatures, mynah birds,..
Second Pepperpot | Yes. When Beethoven went deaf the mynah bird just used to mime.
| The picture begins to wobble as in flashback; appropriate dreamy music effect.
First Pepperpot | (looking at camera) Ooh! What's happening?
Second Pepperpot | It's all right. It's only a flashback.
| Cut to Beethoven's living room. A model mynah bird is opening and shutting its beak. Beethoven is sitting at the piano.
Beethoven | You don't fool me, you stupid mynah bird. I'm not deaf yet.
Mynah | Just you wait... ha, ha, ha, ha, ha! (Beethoven pulls a revolver and shoots the bird which falls to the ground) Oh! Bugger...
Beethoven | Shut up!
Mynah | Right in the wing.
Beethoven | Shut your beak. Gott in Himmel... I never get any peace here.
| He plays the first few notes of the fifth symphony, trying vainly to get the last note. Mrs Beethoven enters.
Mrs Beethoven | Ludwig!
Beethoven | What?
Mrs Beethoven | Have you seen the sugar bowl?
Beethoven | No, I haven't seen the bloody sugar bowl.
Mrs Beethoven | You know ... the sugar bowl.
Beethoven | Sod the sugar bowl... I'm trying to finish this stinking tune! It's driving me spare ... so shut up! (she leaves; he goes into opening bars of 'Washington Post March ) No, no, no, no, no.
| Mrs Beethoven comes back in.
Mrs Beethoven | Ludwig, have you seen the jam spoon?
Beethoven | Stuff the jam spoon!
Mrs Beethoven | It was in the sugar bowl.
Beethoven | Look, get out you old rat-bag. Buzz off and shut up.
Mrs Beethoven | I don't know what you see in that piano. (she goes)
Beethoven | Leave me alone!! ... (gets the first eight notes right at last) ... Ha! ha! ha! I've done it, I've done it!
| Mrs Beethoven comes in again.
Mrs Beethoven | Do you want peanut butter or sandwich spread for your tea?
Beethoven | What!!!!
Mrs Beethoven | PEANUT BUTTER...
Beethoven | I've forgotten it. (plays a few wrong notes) I had it! I had it!
Mrs Beethoven | Do you want peanut butter or sandwich spread?
Beethoven | I don't care!!
Mrs Beethoven | Ooooh! I don't know. (she goes out)
Beethoven | I had it. I had it you old bag. (at the same moment as he gets it right again, the door flies open and Mrs Beethoven charges in with a very load vacuum) Mein lieber Gott. What are you doing? (a terrible clanking and banging comes from the wall) What's that! What's that!
Mrs Beethoven | (still vacuuming loudly) It's the plumber!
| A jarring ring of the doorbell adds to the din.
Beethoven | Gott in Himmel, I'm going out.
Mrs Beethoven | Well, if you're going out don't forget we've got the Mendelssohns coming for tea so don't forget to order some pikelets.
Beethoven | Pikelets, pikelets. Shakespeare never had this trouble.
| Shakespeare washing up at a sink present day.
Shakespeare | You wanna bet? Incidentally, its da-da-da-dum, da-da-da-dum.
| Cut back to Beethoven.
Beethoven | You're right. Oh, incidentally, why not call him Hamlet?
| Cut back to Shakespeare
Shakespeare | Hamlet I like much better than David. (he shouts through open window next to sink) Michelangelo! You can use David. I won't sue
| Cut to Michelangelo's studio. Michelangelo is in middle of feeding and looking after at least six screaming little babies. His statue of David is in the foreground.
Michelangelo | Thanks, but I've had a better idea.
| Camera pans down to show engraved on plinth beneath statue the words 'Michelangelo's Fifth Symphony'.
Wife | (off-screen) Michelangelo!
Michelangelo | Yes, dear!
Wife | I've had another son.
Michelangelo | Oh, my life.
| Cut to Mozart. He is scrubbing the floor. CAPTION: 'W. A. MOZART'
Mozart | (Jewish accent) Composer? Huh! I wouldn't wish it on my son. He's a sensitive boy, already. I'd rather he was a sewage attendant or a ratcatcher.
| Cut to street with old-fashioned shops. Exterior. Camera tracks in to a shopfront with a large sign outside: 'Rodent Exterminating Boutique - Colin "Chopper" Mozart (Son Of Composer) Ratcatcher To The Nobility And Ordinary People, Too - Ici On Parle Portugaise'. At the door of shop stands Colin Mozart. A kid runs up to him bearing a long cleft stick, Mozart takes the note from the cleavage and reads it.
Colin Mozart | Aha! Rats at 42a Kartoffelnstrasse. Hey Mitzi! I gotta go to Potato Street.
Mitzi | (off-screen) Put your galoshes on.
| Mozart leaps on to a bike carrying two shrimp-nets, and rides off. SUPERIMPOSED CAPTION: 'MUNICH 1821'
Colin Mozart | (shouting) Depressed by rats? Do mice get you down? Then why not visit Colin Mozart's Rodent Extermination Boutique. Rats extirpated, mice punished, voles torn apart by Colin Mozart, Munich's leading furry animal liquidator.
| Colin Mozart cycles up to Beethoven's house. Outside is a noticeboard saying: MR AND MRS EMMANUEL KANT FRAU MITZI HANDGEPACKAUFBEWAHRUNG MR DICKIE WAGNER K. TYNAN (NO RELATION) MR AND MRSJ. W. VON GOETHE AND DOG HERR E. W. SWANTON MR AND MRS P. ANKA MR AND MRS LUDWIG VAN BEETHOVEN (1770-1827) ACCEPT NO SUBSTITUTE CAPTION: '13.4 SECONDS LATER' Beethoven's front door is opened by Mrs Beethoven.
Mrs Beethoven | Yes?
Colin Mozart | Colin Mozart.
Mrs Beethoven | Oh, thank goodness you've come. We're having a terrible time with them bleeding rats. I think they live in his stupid piano already.
| They go into the house. We hear the first two bars of Beethoven's Fifth counterpointed by loud squeaking.
Beethoven's Voice | Get out the bloody piano you stupid furry bucktoothed gits! Get out! Gott in Himmel. Get your stinking tail out of my face.
| Mrs Beethoven opens the door and we see for the first time a strange sight. Rats are flying across the room (thrown from out of vision) others scuttle across floor (pulled by strings) others up wall. One sits on Beethoven's head. The squealing is deafening. Beethoven plays on relentlessly. Mozart and Mrs Beethoven run into room and start trying to catch the rats with the shrimp-nets. CAPTION: '13.4 MINUTES LATER' Colin Mozart is sitting on the piano. He rakes the rat-infested room with machine-gunfire.
Beethoven | Shut up!
| The picture starts to wobble and mixes back to the two pepperpots.
Second Pepperpot | So anyway, Beethoven was rather glad when he went deaf.
| Mix to Beethoven pushing the keys of the keyboard which is all that remains of his piano. He listens vainly. The mynah bird opens and shuts its beak. In the corner an old horn gramophone plays. We hear Jimmy Durante singing the end of 'I'm the guy that found the lost chord'. Cut back to judges' robing room.
First Judge | Well, I was ever so glad they abolished hanging, you know, because that black cap just didn't suit me.
Second Judge | Yes. Do you remember the Glasgow treason trial?
First Judge | Oh yes, I wore a body stocking all through it.
Second Judge | No, hen, with the party afterwards.
First Judge | Oh, that's right. You were walking out with that very butch Clerk of the Court.
Second Judge | That's right. Ooh, he made me want to turn Queen's evidence.
| Superimposed credits. Theme tune heard quietly as judges continue.
First Judge | Oh, me too. One summing up and I'm anybody's.
Second Judge | Anyway, Bailie Anderson.
First Judge | Ooh, her?
Second Judge | Yes. She's so strict. She was on at me for giving dolly sentences, you know, specially in that arson case.
First Judge | What was the verdict?
Second Judge | They preferred the brown wig.
First Judge | Mm. I love the Scottish Assizes. I know what they mean by a really well-hung jury.
Second Judge | Ooh! Get back in the witness box, you're too sharp to live!
First Judge | I'll smack your little botty!
Second Judge | Ooh! and again.
First Judge | Have you tried that new body rub JP's use?
Second Judge | I had a magistrate in Bradford yesterday.
First Judge | Funnily enough I felt like one in a lunchtime recess today. (credits end) But the ones I really like are those voice over announcers on the BBC after the programs are over.
Second Judge | Oh, aye, of course, they're as bent as safety pins.
First Judge | I know, but they've got beautiful speaking voices, haven't they? 'And now a choice of viewing on BBC Television.'
Second Judge | 'Here are tonight's football results.'
First and Second Judges | Mmm.
| Fade out.